@@ -160,6 +160,32 @@ class ALFAbyDate:
                 'frequency': 'daily',  # '2dayOfMonth,Friday'
                 'delay': 1
             },
+            'teacher_hour': {
+                'platform': 'alfa',
+                'report_name': 'teacher_hour',
+                'upload_table': 'teacher_hour',
+                'func_name': self.get_teacher_hour,
+                'uniq_columns': 'id',
+                'partitions': '',
+                'merge_type': 'ReplacingMergeTree(timeStamp)',
+                'refresh_type': 'delete_all',
+                'history': False,
+                'frequency': 'daily',  # '2dayOfMonth,Friday'
+                'delay': 1
+            },
+            'teacher_rate': {
+                'platform': 'alfa',
+                'report_name': 'teacher_rate',
+                'upload_table': 'teacher_rate',
+                'func_name': self.get_teacher_rate,
+                'uniq_columns': 'id',
+                'partitions': '',
+                'merge_type': 'ReplacingMergeTree(timeStamp)',
+                'refresh_type': 'delete_all',
+                'history': False,
+                'frequency': 'daily',  # '2dayOfMonth,Friday'
+                'delay': 1
+            },
             'subject': {
                 'platform': 'alfa',
                 'report_name': 'subject',
@@ -948,6 +974,32 @@ class ALFAbyDate:
             self.common.log_func(self.bot_token, self.chat_list, message, 3)
             return message
 
+    def get_teacher_rate(self, date):
+        try:
+            final_result = []
+            for branch in self.branches_list:
+                final_result += self.get_basic(f'v2api/{str(branch).strip()}/teacher/teacher-rate', )
+            message = f'Платформа: ALFA. Имя: {self.add_name}. Дата: {str(date)}. Функция: get_teacher_rate. Результат: ОК'
+            self.common.log_func(self.bot_token, self.chat_list, message, 1)
+            return final_result
+        except Exception as e:
+            message = f'Платформа: ALFA. Имя: {self.add_name}. Дата: {str(date)}. Функция: get_teacher_rate. Ошибка: {e}.'
+            self.common.log_func(self.bot_token, self.chat_list, message, 3)
+            return message
+
+    def get_teacher_hour(self, date):
+        try:
+            final_result = []
+            for branch in self.branches_list:
+                final_result += self.get_basic(f'v2api/{str(branch).strip()}/teacher/working-hour', )
+            message = f'Платформа: ALFA. Имя: {self.add_name}. Дата: {str(date)}. Функция: get_teacher_hour. Результат: ОК'
+            self.common.log_func(self.bot_token, self.chat_list, message, 1)
+            return final_result
+        except Exception as e:
+            message = f'Платформа: ALFA. Имя: {self.add_name}. Дата: {str(date)}. Функция: get_teacher_hour. Ошибка: {e}.'
+            self.common.log_func(self.bot_token, self.chat_list, message, 3)
+            return message
+
 
     def collecting_manager(self):
         self.auth()
