@@ -235,6 +235,19 @@ class OZONbyDate:
                 'frequency': '1,16',  # '2,Friday'
                 'delay': 30
             },
+            'products_buyout': {
+            'platform': 'ozon',
+            'report_name': 'products_buyout',
+            'upload_table': 'products_buyout',
+            'func_name': self.get_products_buyout,
+            'uniq_columns': 'offer_id,sku,posting_number',
+            'partitions': '',
+            'merge_type': 'ReplacingMergeTree(timeStamp)',
+            'refresh_type': 'nothing',
+            'history': True,
+            'frequency': 'daily',  # '2,Friday'
+            'delay': 30
+        },
         }
 
     def create_postings_report(self, date, report_type):
@@ -970,6 +983,32 @@ class OZONbyDate:
             self.common.log_func(self.bot_token, self.chat_list, message, 3)
             return message
 
+    def get_products_buyout(self, date):
+        try:
+            data = {"date_from": date, "date_to": date}
+            headers = {
+                "Client-Id": self.clientid,
+                "Api-Key": self.token,
+                "Content-Type": "application/json"
+            }
+            url = "https://api-seller.ozon.ru/v1/finance/products/buyout"
+            response = requests.post(url, json=data, headers=headers)
+            code = response.status_code
+            if code == 429:
+                self.err429 = True
+            if code == 200:
+                result = response.json().get('products', [])
+                final_result = result
+            else:
+                response.raise_for_status()
+            message = f'Платформа: OZON. Имя: {self.add_name}. Дата: {date}. Функция: get_products_buyout. Результат: ОК'
+            self.common.log_func(self.bot_token, self.chat_list, message, 1)
+            return final_result
+        except Exception as e:
+            message = f'Платформа: OZON. Имя: {self.add_name}. Дата: {date}. Функция: get_products_buyout. Ошибка: {e}.'
+            self.common.log_func(self.bot_token, self.chat_list, message, 3)
+            return message
+
 
     def collecting_manager(self):
         report_list = self.reports.replace(' ', '').lower().split(',')
